![](https://img.shields.io/badge/Language-Python3-orange.svg)
![](https://img.shields.io/badge/version-1.0.0-green.svg)
![](https://img.shields.io/badge/License-GPL3-blue.svg)

# CaveFinder
This is a simple tool to look for code caves of desired dimension into an executable file and optionally can inject a payload into the found caves.

CaveFinder supports three types of executables:
- Elf
- MachO
- Pe

## Installation
The package can be installed through pip:

    $ pip install cavefinder

or downloaded from [GitHub](https://github.com/jacopodl/cavefinder).

## License ##
Made with :heartpulse: by <b>JDL</b> and released under <b>GPL3 license</b>.
